khmerML
============

khmerML is an opensource Python module for machine learning that consists of machine learning algorithms building from scratch focus on solving complex problems in Cambodia society. It has developed by slash research team and it will be able to contribute by anybody that willing to share their research.

khmerML also is a way to encourage Cambodian tech engineers to start learning Machine Learning.


Installation
============

Manually Install
----------------
- Python (>= 3.4)
- NumPy (>= 1.14.2)
- nltk (>= 3.2.4)

User Installation
----------------
- python3 setup.py install --record files.txt
- note setup.py that located in khmer-ml root folder


Development
===========

Dataset
-------
- download dataset from https://goo.gl/63c7P4
- create dataset folder under data folder
- extract and put in data/dataset folder

Pytest Installatioin
--------------------
- https://docs.pytest.org/en/latest/getting-started.html or
- pip3 install -U pytest ( or sudo -H pip install pytest --ignore-installed six)
- To run pytest with python3 >>> python3 -m pytest

Editor
--------------
- Visual Code recommended (https://code.visualstudio.com/)
- plugins (recommended)
  * Python
  * Pylint
  * EditorConfig
  * GitLens
  * Sublime Text Keymap (Sublime fan recommended)

Development Usage
===========

Run from main file
------------------
~~~~~~~~~~~~~~~~~
- python3 main.py (note: main.py is located in khmer-ml root folder)
~~~~~~~~~~~~~~~~~

Run from example
----------------
~~~~~~~~~~~~~~~~~
- Chatbot Example (note located folder to khmer-ml)
  * To Train: python3 examples/chatbot/main.py --mode train
  * To Run Chatbot: python3 examples/chatbot/main.py --mode chat
~~~~~~~~~~~~~~~~~

Authors
================
* YIN SENG (Kevin)
* PECH RATHA
* CHAB PISETH
See also the list of [contributors](https://www.slash.co) who participated in this project.

Help and Support (coming soon)
================

Documentation
-------------
* HTML documentation (stable release): https://khmerml.ai
* HTML documentation (development version): https://khmerml.ai/dev/
* FAQ: https://khmerml.ai/faq

Communication
-------------
* Subscribe khmerml: https://khmerml.ai/subscribe
* Slack channel
* Stack Overflow
* Website: https://khmerml.ai

